@@ -22,12 +22,12 @@ from collections.abc import (
     Sequence,
 )
 from datetime import datetime
+from itertools import chain
 from pathlib import Path
 from timeit import default_timer as timer
 from types import SimpleNamespace
 from typing import TYPE_CHECKING, Any, BinaryIO, ParamSpec, get_args, get_type_hints
 
-from fastapi import FastAPI
 from rich.progress import MofNCompleteColumn, Progress, TimeElapsedColumn
 from socketio import ASGIApp as EngineIOApp
 from socketio import AsyncNamespace, AsyncServer
@@ -238,10 +238,6 @@ def default_error_boundary(*children: Component, **props) -> Component:
     )
 
 
-class OverlayFragment(Fragment):
-    """Alias for Fragment, used to wrap the overlay_component."""
-
-
 @dataclasses.dataclass(frozen=True)
 class UploadFile(StarletteUploadFile):
     """A file uploaded to the server.
@@ -369,6 +365,11 @@ class App(MiddlewareMixin, LifespanMixin):
         )
     )
 
+    # Extra app wraps to be applied to the whole app.
+    extra_app_wraps: dict[tuple[int, str], Callable[[bool], Component | None]] = (
+        dataclasses.field(default_factory=dict)
+    )
+
     # Components to add to the head of every page.
     head_components: list[Component] = dataclasses.field(default_factory=list)
 
@@ -398,6 +399,9 @@ class App(MiddlewareMixin, LifespanMixin):
     # The state class to use for the app.
     _state: type[BaseState] | None = None
 
+    # Whether to enable state for the app. If False, the app will not use state.
+    enable_state: bool = True
+
     # Class to manage many client states.
     _state_manager: StateManager | None = None
 
@@ -436,9 +440,6 @@ class App(MiddlewareMixin, LifespanMixin):
         | None
     ) = None
 
-    # FastAPI app for compatibility with FastAPI.
-    _cached_fastapi_app: FastAPI | None = None
-
     @property
     def event_namespace(self) -> EventNamespace | None:
         """Get the event namespace.
@@ -478,7 +479,8 @@ class App(MiddlewareMixin, LifespanMixin):
             if issubclass(clz, AppMixin):
                 clz._init_mixin(self)
 
-        self._setup_state()
+        if self.enable_state:
+            self._enable_state()
 
         # Set up the admin dash.
         self._setup_admin_dash()
@@ -493,7 +495,7 @@ class App(MiddlewareMixin, LifespanMixin):
         """Enable state for the app."""
         if not self._state:
             self._state = State
-            self._setup_state()
+        self._setup_state()
 
     def _setup_state(self) -> None:
         """Set up the state for the app.
@@ -515,8 +517,8 @@ class App(MiddlewareMixin, LifespanMixin):
                 async_mode="asgi",
                 cors_allowed_origins=(
                     "*"
-                    if config.cors_allowed_origins == ["*"]
-                    else config.cors_allowed_origins
+                    if config.cors_allowed_origins == ("*",)
+                    else list(config.cors_allowed_origins)
                 ),
                 cors_credentials=True,
                 max_http_buffer_size=environment.REFLEX_SOCKET_MAX_HTTP_BUFFER_SIZE.get(),
@@ -592,32 +594,22 @@ class App(MiddlewareMixin, LifespanMixin):
         Returns:
             The backend api.
         """
+        from reflex.vars.base import GLOBAL_CACHE
+
         # For py3.9 compatibility when redis is used, we MUST add any decorator pages
         # before compiling the app in a thread to avoid event loop error (REF-2172).
         self._apply_decorated_pages()
 
-        compile_future = concurrent.futures.ThreadPoolExecutor(max_workers=1).submit(
-            self._compile, prerender_routes=is_prod_mode()
-        )
+        self._compile(prerender_routes=is_prod_mode())
 
-        def callback(f: concurrent.futures.Future):
-            # Force background compile errors to print eagerly
-            return f.result()
-
-        compile_future.add_done_callback(callback)
-        # Wait for the compile to finish to ensure all optional endpoints are mounted.
-        compile_future.result()
+        # We will not be making more vars, so we can clear the global cache to free up memory.
+        GLOBAL_CACHE.clear()
 
         if not self._api:
             msg = "The app has not been initialized."
             raise ValueError(msg)
 
-        if self._cached_fastapi_app is not None:
-            asgi_app = self._cached_fastapi_app
-            asgi_app.mount("", self._api)
-            App._add_cors(asgi_app)
-        else:
-            asgi_app = self._api
+        asgi_app = self._api
 
         if self.api_transformer is not None:
             api_transformers: Sequence[Starlette | Callable[[ASGIApp], ASGIApp]] = (
@@ -845,14 +837,10 @@ class App(MiddlewareMixin, LifespanMixin):
             save_page: If True, the compiled page is saved to self._pages.
         """
         n_states_before = len(all_base_state_classes)
-        component, enable_state = compiler.compile_unevaluated_page(
-            route, self._unevaluated_pages[route], self._state, self.style, self.theme
+        component = compiler.compile_unevaluated_page(
+            route, self._unevaluated_pages[route], self.style, self.theme
         )
 
-        # Indicate that the app should use state.
-        if enable_state:
-            self._enable_state()
-
         # Indicate that evaluating this page creates one or more state classes.
         if len(all_base_state_classes) > n_states_before:
             self._stateful_pages[route] = None
@@ -1031,25 +1019,31 @@ class App(MiddlewareMixin, LifespanMixin):
         # By default, compile the app.
         return True
 
-    def _add_overlay_to_component(self, component: Component) -> Component:
-        if self.overlay_component is None:
-            return component
-
+    def _add_overlay_to_component(
+        self, component: Component, overlay_component: Component
+    ) -> Component:
         children = component.children
-        overlay_component = self._generate_component(self.overlay_component)
 
         if children[0] == overlay_component:
             return component
 
-        # recreate OverlayFragment with overlay_component as first child
-        return OverlayFragment.create(overlay_component, *children)
+        return Fragment.create(overlay_component, *children)
 
     def _setup_overlay_component(self):
         """If a State is not used and no overlay_component is specified, do not render the connection modal."""
-        if self._state is None and self.overlay_component is default_overlay_component:
-            self.overlay_component = None
+        if self.overlay_component is None:
+            return
+        console.deprecate(
+            feature_name="overlay_component",
+            reason="Use `extra_app_wraps` to add the overlay component instead.",
+            deprecation_version="0.8.2",
+            removal_version="0.9.0",
+        )
+        overlay_component = self._generate_component(self.overlay_component)
         for k, component in self._pages.items():
-            self._pages[k] = self._add_overlay_to_component(component)
+            self._pages[k] = self._add_overlay_to_component(
+                component, overlay_component
+            )
 
     def _setup_sticky_badge(self):
         """Add the sticky badge to the app."""
@@ -1138,7 +1132,6 @@ class App(MiddlewareMixin, LifespanMixin):
                 for route in stateful_pages:
                     console.debug(f"BE Evaluating stateful page: {route}")
                     self._compile_page(route, save_page=False)
-                self._enable_state()
             self._add_optional_endpoints()
             return
 
@@ -1193,8 +1186,8 @@ class App(MiddlewareMixin, LifespanMixin):
         progress.start()
         task = progress.add_task(
             f"[{get_compilation_time()}] Compiling:",
-            total=len(self._pages)
-            + (len(self._unevaluated_pages) * 2)
+            total=len(self._unevaluated_pages)
+            + ((len(self._unevaluated_pages) + len(self._pages)) * 3)
             + fixed_pages_within_executor
             + adhoc_steps_without_executor
             + plugin_count,
@@ -1261,7 +1254,10 @@ class App(MiddlewareMixin, LifespanMixin):
             app_wrappers[(1, "ToasterProvider")] = toast_provider
 
         # Add the app wraps to the app.
-        for key, app_wrap in self.app_wraps.items():
+        for key, app_wrap in chain(
+            self.app_wraps.items(), self.extra_app_wraps.items()
+        ):
+            # If the app wrap is a callable, generate the component
             component = app_wrap(self._state is not None)
             if component is not None:
                 app_wrappers[key] = component
@@ -1276,14 +1272,17 @@ class App(MiddlewareMixin, LifespanMixin):
         all_imports.update(custom_components_imports)
         progress.advance(task)
 
-        # This has to happen before compiling stateful components as that
-        # prevents recursive functions from reaching all components.
-        for component in self._pages.values():
-            # Add component._get_all_imports() to all_imports.
-            all_imports.update(component._get_all_imports())
+        with console.timing("Collect all imports and app wraps"):
+            # This has to happen before compiling stateful components as that
+            # prevents recursive functions from reaching all components.
+            for component in self._pages.values():
+                # Add component._get_all_imports() to all_imports.
+                all_imports.update(component._get_all_imports())
 
-            # Add the app wrappers from this component.
-            app_wrappers.update(component._get_all_app_wrap_components())
+                # Add the app wrappers from this component.
+                app_wrappers.update(component._get_all_app_wrap_components())
+
+                progress.advance(task)
 
         # Perform auto-memoization of stateful components.
         with console.timing("Auto-memoize StatefulComponents"):
@@ -1291,7 +1290,10 @@ class App(MiddlewareMixin, LifespanMixin):
                 stateful_components_path,
                 stateful_components_code,
                 page_components,
-            ) = compiler.compile_stateful_components(self._pages.values())
+            ) = compiler.compile_stateful_components(
+                self._pages.values(),
+                progress_function=lambda task=task: progress.advance(task),
+            )
             progress.advance(task)
 
         # Catch "static" apps (that do not define a rx.State subclass) which are trying to access rx.State.
@@ -1334,8 +1336,6 @@ class App(MiddlewareMixin, LifespanMixin):
         for route, component in zip(self._pages, page_components, strict=True):
             ExecutorSafeFunctions.COMPONENTS[route] = component
 
-        ExecutorSafeFunctions.STATE = self._state
-
         modify_files_tasks: list[tuple[str, str, Callable[[str], str]]] = []
 
         with console.timing("Compile to Javascript"), executor as executor:
@@ -2076,9 +2076,20 @@ class EventNamespace(AsyncNamespace):
         # Get the client IP
         try:
             client_ip = environ["asgi.scope"]["client"][0]
+            headers["asgi-scope-client"] = client_ip
         except (KeyError, IndexError):
             client_ip = environ.get("REMOTE_ADDR", "0.0.0.0")
 
+        # Unroll reverse proxy forwarded headers.
+        client_ip = (
+            headers.get(
+                "x-forwarded-for",
+                client_ip,
+            )
+            .partition(",")[0]
+            .strip()
+        )
+
         async with contextlib.aclosing(
             process(self.app, event, sid, headers, client_ip)
         ) as updates_gen:
