@@ -3,7 +3,7 @@
 from __future__ import annotations
 
 import sys
-from collections.abc import Iterable, Sequence
+from collections.abc import Callable, Iterable, Sequence
 from inspect import getmodule
 from pathlib import Path
 from typing import TYPE_CHECKING
@@ -145,15 +145,11 @@ def _compile_contexts(state: type[BaseState] | None, theme: Component | None) ->
     )
 
 
-def _compile_page(
-    component: BaseComponent,
-    state: type[BaseState] | None,
-) -> str:
-    """Compile the component given the app state.
+def _compile_page(component: BaseComponent) -> str:
+    """Compile the component.
 
     Args:
         component: The component to compile.
-        state: The app state.
 
     Returns:
         The compiled component.
@@ -163,15 +159,12 @@ def _compile_page(
     imports = utils.compile_imports(imports)
 
     # Compile the code to render the component.
-    kwargs = {"state_name": state.get_name()} if state is not None else {}
-
     return templates.PAGE.render(
         imports=imports,
         dynamic_imports=component._get_all_dynamic_imports(),
         custom_codes=component._get_all_custom_code(),
         hooks=component._get_all_hooks(),
         render=component.render(),
-        **kwargs,
     )
 
 
@@ -556,15 +549,12 @@ def compile_contexts(
     return output_path, _compile_contexts(state, theme)
 
 
-def compile_page(
-    path: str, component: BaseComponent, state: type[BaseState] | None
-) -> tuple[str, str]:
+def compile_page(path: str, component: BaseComponent) -> tuple[str, str]:
     """Compile a single page.
 
     Args:
         path: The path to compile the page to.
         component: The component to compile.
-        state: The app state.
 
     Returns:
         The path and code of the compiled page.
@@ -573,7 +563,7 @@ def compile_page(
     output_path = utils.get_page_path(path)
 
     # Add the style to the component.
-    code = _compile_page(component, state)
+    code = _compile_page(component)
     return output_path, code
 
 
@@ -598,6 +588,7 @@ def compile_components(
 
 def compile_stateful_components(
     pages: Iterable[Component],
+    progress_function: Callable[[], None],
 ) -> tuple[str, str, list[BaseComponent]]:
     """Separately compile components that depend on State vars.
 
@@ -607,14 +598,20 @@ def compile_stateful_components(
 
     Args:
         pages: The pages to extract stateful components from.
+        progress_function: A function to call to indicate progress, called once per page.
 
     Returns:
         The path and code of the compiled stateful components.
     """
     output_path = utils.get_stateful_components_path()
 
-    # Compile the stateful components.
-    page_components = [StatefulComponent.compile_from(page) or page for page in pages]
+    page_components = []
+    for page in pages:
+        # Compile the stateful components
+        page_component = StatefulComponent.compile_from(page) or page
+        progress_function()
+        page_components.append(page_component)
+
     code = _compile_stateful_components(page_components)
     return output_path, code, page_components
 
@@ -788,16 +785,14 @@ def into_component(component: Component | ComponentCallable) -> Component:
 def compile_unevaluated_page(
     route: str,
     page: UnevaluatedPage,
-    state: type[BaseState] | None = None,
     style: ComponentStyle | None = None,
     theme: Component | None = None,
-) -> tuple[Component, bool]:
+) -> Component:
     """Compiles an uncompiled page into a component and adds meta information.
 
     Args:
         route: The route of the page.
         page: The uncompiled page object.
-        state: The state of the app.
         style: The style of the page.
         theme: The theme of the page.
 
@@ -813,25 +808,9 @@ def compile_unevaluated_page(
 
         component._add_style_recursive(style or {}, theme)
 
-        enable_state = False
-        # Ensure state is enabled if this page uses state.
-        if state is None:
-            if page.on_load or component._has_stateful_event_triggers():
-                enable_state = True
-            else:
-                for var in component._get_vars(include_children=True):
-                    var_data = var._get_all_var_data()
-                    if not var_data:
-                        continue
-                    if not var_data.state:
-                        continue
-                    enable_state = True
-                    break
-
-        from reflex.app import OverlayFragment
         from reflex.utils.format import make_default_page_title
 
-        component = OverlayFragment.create(component)
+        component = Fragment.create(component)
 
         meta_args = {
             "title": (
@@ -857,7 +836,7 @@ def compile_unevaluated_page(
             e.add_note(f"Happened while evaluating page {route!r}")
         raise
     else:
-        return component, enable_state
+        return component
 
 
 class ExecutorSafeFunctions:
@@ -887,7 +866,6 @@ class ExecutorSafeFunctions:
 
     COMPONENTS: dict[str, BaseComponent] = {}
     UNCOMPILED_PAGES: dict[str, UnevaluatedPage] = {}
-    STATE: type[BaseState] | None = None
 
     @classmethod
     def compile_page(cls, route: str) -> tuple[str, str]:
@@ -899,7 +877,7 @@ class ExecutorSafeFunctions:
         Returns:
             The path and code of the compiled page.
         """
-        return compile_page(route, cls.COMPONENTS[route], cls.STATE)
+        return compile_page(route, cls.COMPONENTS[route])
 
     @classmethod
     def compile_unevaluated_page(
@@ -918,10 +896,10 @@ class ExecutorSafeFunctions:
         Returns:
             The route, compiled component, and compiled page.
         """
-        component, enable_state = compile_unevaluated_page(
-            route, cls.UNCOMPILED_PAGES[route], cls.STATE, style, theme
+        component = compile_unevaluated_page(
+            route, cls.UNCOMPILED_PAGES[route], style, theme
         )
-        return route, component, compile_page(route, component, cls.STATE)
+        return route, component, compile_page(route, component)
 
     @classmethod
     def compile_theme(cls, style: ComponentStyle | None) -> tuple[str, str]:
