@@ -12,6 +12,7 @@ from reflex.components.el.element import Element
 from reflex.components.tags.tag import Tag
 from reflex.constants import Dirs, EventTriggers
 from reflex.event import (
+    FORM_DATA,
     EventChain,
     EventHandler,
     checked_input_event,
@@ -19,6 +20,8 @@ from reflex.event import (
     input_event,
     int_input_event,
     key_event,
+    on_submit_event,
+    on_submit_string_event,
     prevent_default,
 )
 from reflex.utils.imports import ImportDict
@@ -28,7 +31,6 @@ from reflex.vars.number import ternary_operation
 
 from .base import BaseHTML
 
-FORM_DATA = Var(_js_expr="form_data")
 HANDLE_SUBMIT_JS_JINJA2 = Environment().from_string(
     """
     const handleSubmit_{{ handle_submit_unique_name }} = useCallback((ev) => {
@@ -110,24 +112,6 @@ class Fieldset(Element):
     name: Var[str]
 
 
-def on_submit_event_spec() -> tuple[Var[dict[str, Any]]]:
-    """Event handler spec for the on_submit event.
-
-    Returns:
-        The event handler spec.
-    """
-    return (FORM_DATA,)
-
-
-def on_submit_string_event_spec() -> tuple[Var[dict[str, str]]]:
-    """Event handler spec for the on_submit event.
-
-    Returns:
-        The event handler spec.
-    """
-    return (FORM_DATA,)
-
-
 class Form(BaseHTML):
     """Display the form element."""
 
@@ -167,7 +151,7 @@ class Form(BaseHTML):
     handle_submit_unique_name: Var[str]
 
     # Fired when the form is submitted
-    on_submit: EventHandler[on_submit_event_spec, on_submit_string_event_spec]
+    on_submit: EventHandler[on_submit_event, on_submit_string_event]
 
     @classmethod
     def create(cls, *children, **props):
@@ -228,7 +212,7 @@ class Form(BaseHTML):
     def _render(self) -> Tag:
         render_tag = super()._render()
         if EventTriggers.ON_SUBMIT in self.event_triggers:
-            render_tag.add_props(
+            render_tag = render_tag.add_props(
                 **{
                     EventTriggers.ON_SUBMIT: Var(
                         _js_expr=f"handleSubmit_{self.handle_submit_unique_name}",
@@ -466,11 +450,13 @@ class Input(BaseInput):
         if cls is Input:
             input_type = props.get("type")
 
-            if input_type == "checkbox":
+            if isinstance(input_type, str) and input_type == "checkbox":
                 # Checkbox inputs should use the CheckboxInput class
                 return CheckboxInput.create(*children, **props)
 
-            if input_type == "number" or input_type == "range":
+            if isinstance(input_type, str) and (
+                input_type == "number" or input_type == "range"
+            ):
                 # Number inputs should use the ValueNumberInput class
                 return ValueNumberInput.create(*children, **props)
 
