@@ -6,7 +6,7 @@ from reflex.utils.imports import ImportVar
 from reflex.vars.base import LiteralVar, Var
 from reflex.vars.sequence import LiteralStringVar, StringVar
 
-LUCIDE_LIBRARY = "lucide-react@0.511.0"
+LUCIDE_LIBRARY = "lucide-react@0.534.0"
 
 
 class LucideIconComponent(Component):
@@ -112,16 +112,16 @@ LUCIDE_ICON_LIST = [
     "activity",
     "air_vent",
     "airplay",
-    "alarm_clock",
     "alarm_clock_check",
     "alarm_clock_minus",
     "alarm_clock_off",
     "alarm_clock_plus",
+    "alarm_clock",
     "alarm_smoke",
     "album",
-    "align_center",
     "align_center_horizontal",
     "align_center_vertical",
+    "align_center",
     "align_end_horizontal",
     "align_end_vertical",
     "align_horizontal_distribute_center",
@@ -155,23 +155,22 @@ LUCIDE_ICON_LIST = [
     "antenna",
     "anvil",
     "aperture",
-    "app_window",
     "app_window_mac",
+    "app_window",
     "apple",
-    "archive",
     "archive_restore",
     "archive_x",
+    "archive",
     "area_chart",
     "armchair",
-    "arrow_big_down",
     "arrow_big_down_dash",
-    "arrow_big_left",
+    "arrow_big_down",
     "arrow_big_left_dash",
-    "arrow_big_right",
+    "arrow_big_left",
     "arrow_big_right_dash",
-    "arrow_big_up",
+    "arrow_big_right",
     "arrow_big_up_dash",
-    "arrow_down",
+    "arrow_big_up",
     "arrow_down_0_1",
     "arrow_down_1_0",
     "arrow_down_a_z",
@@ -184,15 +183,15 @@ LUCIDE_ICON_LIST = [
     "arrow_down_up",
     "arrow_down_wide_narrow",
     "arrow_down_z_a",
-    "arrow_left",
+    "arrow_down",
     "arrow_left_from_line",
     "arrow_left_right",
     "arrow_left_to_line",
-    "arrow_right",
+    "arrow_left",
     "arrow_right_from_line",
     "arrow_right_left",
     "arrow_right_to_line",
-    "arrow_up",
+    "arrow_right",
     "arrow_up_0_1",
     "arrow_up_1_0",
     "arrow_up_a_z",
@@ -205,6 +204,7 @@ LUCIDE_ICON_LIST = [
     "arrow_up_to_line",
     "arrow_up_wide_narrow",
     "arrow_up_z_a",
+    "arrow_up",
     "arrows_up_from_line",
     "asterisk",
     "at_sign",
@@ -216,7 +216,6 @@ LUCIDE_ICON_LIST = [
     "axis_3d",
     "baby",
     "backpack",
-    "badge",
     "badge_alert",
     "badge_cent",
     "badge_check",
@@ -232,47 +231,50 @@ LUCIDE_ICON_LIST = [
     "badge_pound_sterling",
     "badge_russian_ruble",
     "badge_swiss_franc",
+    "badge_turkish_lira",
     "badge_x",
+    "badge",
     "baggage_claim",
     "ban",
     "banana",
     "bandage",
-    "banknote",
     "banknote_arrow_down",
     "banknote_x",
-    "bar_chart",
+    "banknote",
     "bar_chart_2",
     "bar_chart_3",
     "bar_chart_4",
     "bar_chart_big",
-    "bar_chart_horizontal",
     "bar_chart_horizontal_big",
+    "bar_chart_horizontal",
+    "bar_chart",
     "barcode",
+    "barrel",
     "baseline",
     "bath",
-    "battery",
     "battery_charging",
     "battery_full",
     "battery_low",
     "battery_medium",
     "battery_plus",
     "battery_warning",
+    "battery",
     "beaker",
-    "bean",
     "bean_off",
-    "bed",
+    "bean",
     "bed_double",
     "bed_single",
+    "bed",
     "beef",
-    "beer",
     "beer_off",
-    "bell",
+    "beer",
     "bell_dot",
     "bell_electric",
     "bell_minus",
     "bell_off",
     "bell_plus",
     "bell_ring",
+    "bell",
     "between_horizontal_end",
     "between_horizontal_start",
     "between_vertical_end",
@@ -287,16 +289,16 @@ LUCIDE_ICON_LIST = [
     "blend",
     "blinds",
     "blocks",
-    "bluetooth",
     "bluetooth_connected",
     "bluetooth_off",
     "bluetooth_searching",
+    "bluetooth",
     "bold",
     "bolt",
     "bomb",
     "bone",
-    "book",
     "book_a",
+    "book_alert",
     "book_audio",
     "book_check",
     "book_copy",
@@ -309,90 +311,93 @@ LUCIDE_ICON_LIST = [
     "book_lock",
     "book_marked",
     "book_minus",
-    "book_open",
     "book_open_check",
     "book_open_text",
+    "book_open",
     "book_plus",
     "book_text",
     "book_type",
-    "book_up",
     "book_up_2",
+    "book_up",
     "book_user",
     "book_x",
-    "bookmark",
+    "book",
     "bookmark_check",
     "bookmark_minus",
     "bookmark_plus",
     "bookmark_x",
+    "bookmark",
     "boom_box",
-    "bot",
     "bot_message_square",
     "bot_off",
+    "bot",
+    "bottle_wine",
     "bow_arrow",
-    "box",
     "box_select",
+    "box",
     "boxes",
     "braces",
     "brackets",
-    "brain",
     "brain_circuit",
     "brain_cog",
-    "brick_wall",
+    "brain",
     "brick_wall_fire",
-    "briefcase",
+    "brick_wall",
     "briefcase_business",
     "briefcase_conveyor_belt",
     "briefcase_medical",
+    "briefcase",
     "bring_to_front",
-    "brush",
     "brush_cleaning",
+    "brush",
     "bubbles",
-    "bug",
     "bug_off",
     "bug_play",
-    "building",
+    "bug",
     "building_2",
-    "bus",
+    "building",
     "bus_front",
-    "cable",
+    "bus",
     "cable_car",
-    "cake",
+    "cable",
     "cake_slice",
+    "cake",
     "calculator",
-    "calendar",
     "calendar_1",
     "calendar_arrow_down",
     "calendar_arrow_up",
-    "calendar_check",
     "calendar_check_2",
+    "calendar_check",
     "calendar_clock",
     "calendar_cog",
     "calendar_days",
     "calendar_fold",
     "calendar_heart",
-    "calendar_minus",
     "calendar_minus_2",
+    "calendar_minus",
     "calendar_off",
-    "calendar_plus",
     "calendar_plus_2",
+    "calendar_plus",
     "calendar_range",
     "calendar_search",
     "calendar_sync",
-    "calendar_x",
     "calendar_x_2",
-    "camera",
+    "calendar_x",
+    "calendar",
     "camera_off",
+    "camera",
     "candlestick_chart",
-    "candy",
     "candy_cane",
     "candy_off",
+    "candy",
     "cannabis",
-    "captions",
     "captions_off",
-    "car",
+    "captions",
     "car_front",
     "car_taxi_front",
+    "car",
     "caravan",
+    "card_sim",
     "carrot",
     "case_lower",
     "case_sensitive",
@@ -403,31 +408,31 @@ LUCIDE_ICON_LIST = [
     "cat",
     "cctv",
     "chart_area",
-    "chart_bar",
     "chart_bar_big",
     "chart_bar_decreasing",
     "chart_bar_increasing",
     "chart_bar_stacked",
+    "chart_bar",
     "chart_candlestick",
-    "chart_column",
     "chart_column_big",
     "chart_column_decreasing",
     "chart_column_increasing",
     "chart_column_stacked",
+    "chart_column",
     "chart_gantt",
     "chart_line",
     "chart_network",
-    "chart_no_axes_column",
     "chart_no_axes_column_decreasing",
     "chart_no_axes_column_increasing",
+    "chart_no_axes_column",
     "chart_no_axes_combined",
     "chart_no_axes_gantt",
     "chart_pie",
     "chart_scatter",
     "chart_spline",
-    "check",
     "check_check",
     "check_line",
+    "check",
     "chef_hat",
     "cherry",
     "chevron_down",
@@ -436,20 +441,19 @@ LUCIDE_ICON_LIST = [
     "chevron_left",
     "chevron_right",
     "chevron_up",
-    "chevrons_down",
     "chevrons_down_up",
-    "chevrons_left",
-    "chevrons_left_right",
+    "chevrons_down",
     "chevrons_left_right_ellipsis",
-    "chevrons_right",
+    "chevrons_left_right",
+    "chevrons_left",
     "chevrons_right_left",
-    "chevrons_up",
+    "chevrons_right",
     "chevrons_up_down",
+    "chevrons_up",
     "chrome",
     "church",
-    "cigarette",
     "cigarette_off",
-    "circle",
+    "cigarette",
     "circle_alert",
     "circle_arrow_down",
     "circle_arrow_left",
@@ -459,8 +463,8 @@ LUCIDE_ICON_LIST = [
     "circle_arrow_out_up_right",
     "circle_arrow_right",
     "circle_arrow_up",
-    "circle_check",
     "circle_check_big",
+    "circle_check",
     "circle_chevron_down",
     "circle_chevron_left",
     "circle_chevron_right",
@@ -468,8 +472,8 @@ LUCIDE_ICON_LIST = [
     "circle_dashed",
     "circle_divide",
     "circle_dollar_sign",
-    "circle_dot",
     "circle_dot_dashed",
+    "circle_dot",
     "circle_ellipsis",
     "circle_equal",
     "circle_fading_arrow_up",
@@ -478,35 +482,37 @@ LUCIDE_ICON_LIST = [
     "circle_help",
     "circle_minus",
     "circle_off",
-    "circle_parking",
     "circle_parking_off",
+    "circle_parking",
     "circle_pause",
     "circle_percent",
     "circle_play",
     "circle_plus",
+    "circle_pound_sterling",
     "circle_power",
-    "circle_slash",
     "circle_slash_2",
+    "circle_slash",
     "circle_small",
     "circle_stop",
-    "circle_user",
     "circle_user_round",
+    "circle_user",
     "circle_x",
+    "circle",
     "circuit_board",
     "citrus",
     "clapperboard",
-    "clipboard",
     "clipboard_check",
+    "clipboard_clock",
     "clipboard_copy",
     "clipboard_list",
     "clipboard_minus",
     "clipboard_paste",
-    "clipboard_pen",
     "clipboard_pen_line",
+    "clipboard_pen",
     "clipboard_plus",
     "clipboard_type",
     "clipboard_x",
-    "clock",
+    "clipboard",
     "clock_1",
     "clock_10",
     "clock_11",
@@ -524,36 +530,39 @@ LUCIDE_ICON_LIST = [
     "clock_arrow_up",
     "clock_fading",
     "clock_plus",
-    "cloud",
+    "clock",
+    "closed_caption",
     "cloud_alert",
+    "cloud_check",
     "cloud_cog",
     "cloud_download",
     "cloud_drizzle",
     "cloud_fog",
     "cloud_hail",
     "cloud_lightning",
-    "cloud_moon",
     "cloud_moon_rain",
+    "cloud_moon",
     "cloud_off",
-    "cloud_rain",
     "cloud_rain_wind",
+    "cloud_rain",
     "cloud_snow",
-    "cloud_sun",
     "cloud_sun_rain",
+    "cloud_sun",
     "cloud_upload",
+    "cloud",
     "cloudy",
     "clover",
     "club",
-    "code",
     "code_xml",
+    "code",
     "codepen",
     "codesandbox",
     "coffee",
     "cog",
     "coins",
     "columns_2",
-    "columns_3",
     "columns_3_cog",
+    "columns_3",
     "columns_4",
     "combine",
     "command",
@@ -563,18 +572,18 @@ LUCIDE_ICON_LIST = [
     "concierge_bell",
     "cone",
     "construction",
-    "contact",
     "contact_round",
+    "contact",
     "container",
     "contrast",
     "cookie",
     "cooking_pot",
-    "copy",
     "copy_check",
     "copy_minus",
     "copy_plus",
     "copy_slash",
     "copy_x",
+    "copy",
     "copyleft",
     "copyright",
     "corner_down_left",
@@ -598,18 +607,18 @@ LUCIDE_ICON_LIST = [
     "currency",
     "cylinder",
     "dam",
-    "database",
     "database_backup",
     "database_zap",
+    "database",
     "decimals_arrow_left",
     "decimals_arrow_right",
     "delete",
     "dessert",
     "diameter",
-    "diamond",
     "diamond_minus",
     "diamond_percent",
     "diamond_plus",
+    "diamond",
     "dice_1",
     "dice_2",
     "dice_3",
@@ -618,19 +627,19 @@ LUCIDE_ICON_LIST = [
     "dice_6",
     "dices",
     "diff",
-    "disc",
     "disc_2",
     "disc_3",
     "disc_album",
+    "disc",
     "divide",
-    "dna",
     "dna_off",
+    "dna",
     "dock",
     "dog",
     "dollar_sign",
     "donut",
-    "door_closed",
     "door_closed_locked",
+    "door_closed",
     "door_open",
     "dot",
     "download",
@@ -638,33 +647,34 @@ LUCIDE_ICON_LIST = [
     "drama",
     "dribbble",
     "drill",
-    "droplet",
+    "drone",
     "droplet_off",
+    "droplet",
     "droplets",
     "drum",
     "drumstick",
     "dumbbell",
-    "ear",
     "ear_off",
-    "earth",
+    "ear",
     "earth_lock",
+    "earth",
     "eclipse",
-    "egg",
     "egg_fried",
     "egg_off",
-    "ellipsis",
+    "egg",
     "ellipsis_vertical",
-    "equal",
+    "ellipsis",
     "equal_approximately",
     "equal_not",
+    "equal",
     "eraser",
     "ethernet_port",
     "euro",
     "expand",
     "external_link",
-    "eye",
     "eye_closed",
     "eye_off",
+    "eye",
     "facebook",
     "factory",
     "fan",
@@ -673,25 +683,24 @@ LUCIDE_ICON_LIST = [
     "fence",
     "ferris_wheel",
     "figma",
-    "file",
     "file_archive",
-    "file_audio",
     "file_audio_2",
+    "file_audio",
     "file_axis_3d",
-    "file_badge",
     "file_badge_2",
-    "file_bar_chart",
+    "file_badge",
     "file_bar_chart_2",
+    "file_bar_chart",
     "file_box",
-    "file_chart_column",
     "file_chart_column_increasing",
+    "file_chart_column",
     "file_chart_line",
     "file_chart_pie",
-    "file_check",
     "file_check_2",
+    "file_check",
     "file_clock",
-    "file_code",
     "file_code_2",
+    "file_code",
     "file_cog",
     "file_diff",
     "file_digit",
@@ -699,73 +708,73 @@ LUCIDE_ICON_LIST = [
     "file_heart",
     "file_image",
     "file_input",
-    "file_json",
     "file_json_2",
-    "file_key",
+    "file_json",
     "file_key_2",
+    "file_key",
     "file_line_chart",
-    "file_lock",
     "file_lock_2",
-    "file_minus",
+    "file_lock",
     "file_minus_2",
+    "file_minus",
     "file_music",
     "file_output",
-    "file_pen",
     "file_pen_line",
+    "file_pen",
     "file_pie_chart",
-    "file_plus",
     "file_plus_2",
+    "file_plus",
     "file_question",
     "file_scan",
-    "file_search",
     "file_search_2",
+    "file_search",
     "file_sliders",
     "file_spreadsheet",
     "file_stack",
     "file_symlink",
     "file_terminal",
     "file_text",
-    "file_type",
     "file_type_2",
+    "file_type",
     "file_up",
     "file_user",
-    "file_video",
     "file_video_2",
-    "file_volume",
+    "file_video",
     "file_volume_2",
+    "file_volume",
     "file_warning",
-    "file_x",
     "file_x_2",
+    "file_x",
+    "file",
     "files",
     "film",
-    "filter",
     "filter_x",
+    "filter",
     "fingerprint",
     "fire_extinguisher",
-    "fish",
     "fish_off",
     "fish_symbol",
-    "flag",
+    "fish",
     "flag_off",
     "flag_triangle_left",
     "flag_triangle_right",
-    "flame",
+    "flag",
     "flame_kindling",
-    "flashlight",
+    "flame",
     "flashlight_off",
-    "flask_conical",
+    "flashlight",
     "flask_conical_off",
+    "flask_conical",
     "flask_round",
-    "flip_horizontal",
     "flip_horizontal_2",
-    "flip_vertical",
+    "flip_horizontal",
     "flip_vertical_2",
-    "flower",
+    "flip_vertical",
     "flower_2",
+    "flower",
     "focus",
     "fold_horizontal",
     "fold_vertical",
-    "folder",
     "folder_archive",
     "folder_check",
     "folder_clock",
@@ -774,27 +783,28 @@ LUCIDE_ICON_LIST = [
     "folder_cog",
     "folder_dot",
     "folder_down",
-    "folder_git",
     "folder_git_2",
+    "folder_git",
     "folder_heart",
     "folder_input",
     "folder_kanban",
     "folder_key",
     "folder_lock",
     "folder_minus",
-    "folder_open",
     "folder_open_dot",
+    "folder_open",
     "folder_output",
     "folder_pen",
     "folder_plus",
     "folder_root",
-    "folder_search",
     "folder_search_2",
+    "folder_search",
     "folder_symlink",
     "folder_sync",
     "folder_tree",
     "folder_up",
     "folder_x",
+    "folder",
     "folders",
     "footprints",
     "forklift",
@@ -804,112 +814,116 @@ LUCIDE_ICON_LIST = [
     "frown",
     "fuel",
     "fullscreen",
-    "funnel",
     "funnel_plus",
     "funnel_x",
-    "gallery_horizontal",
+    "funnel",
     "gallery_horizontal_end",
+    "gallery_horizontal",
     "gallery_thumbnails",
-    "gallery_vertical",
     "gallery_vertical_end",
-    "gamepad",
+    "gallery_vertical",
     "gamepad_2",
+    "gamepad",
     "gantt_chart",
     "gauge",
     "gavel",
     "gem",
+    "georgian_lari",
     "ghost",
     "gift",
-    "git_branch",
     "git_branch_plus",
+    "git_branch",
     "git_commit_horizontal",
     "git_commit_vertical",
-    "git_compare",
     "git_compare_arrows",
+    "git_compare",
     "git_fork",
     "git_graph",
     "git_merge",
-    "git_pull_request",
     "git_pull_request_arrow",
     "git_pull_request_closed",
-    "git_pull_request_create",
     "git_pull_request_create_arrow",
+    "git_pull_request_create",
     "git_pull_request_draft",
+    "git_pull_request",
     "github",
     "gitlab",
     "glass_water",
     "glasses",
-    "globe",
     "globe_lock",
+    "globe",
     "goal",
     "gpu",
     "grab",
     "graduation_cap",
     "grape",
-    "grid_2x2",
-    "grid_2x_2",
     "grid_2x_2_check",
     "grid_2x_2_plus",
     "grid_2x_2_x",
-    "grid_3x3",
+    "grid_2x_2",
+    "grid_2x2",
     "grid_3x_3",
-    "grip",
+    "grid_3x2",
+    "grid_3x3",
     "grip_horizontal",
     "grip_vertical",
+    "grip",
     "group",
     "guitar",
     "ham",
     "hamburger",
     "hammer",
-    "hand",
     "hand_coins",
     "hand_heart",
     "hand_helping",
     "hand_metal",
     "hand_platter",
+    "hand",
+    "handbag",
     "handshake",
-    "hard_drive",
     "hard_drive_download",
     "hard_drive_upload",
+    "hard_drive",
     "hard_hat",
     "hash",
+    "hat_glasses",
     "haze",
     "hdmi_port",
-    "heading",
     "heading_1",
     "heading_2",
     "heading_3",
     "heading_4",
     "heading_5",
     "heading_6",
+    "heading",
     "headphone_off",
     "headphones",
     "headset",
-    "heart",
     "heart_crack",
     "heart_handshake",
     "heart_minus",
     "heart_off",
     "heart_plus",
     "heart_pulse",
+    "heart",
     "heater",
     "hexagon",
     "highlighter",
     "history",
     "home",
-    "hop",
     "hop_off",
+    "hop",
     "hospital",
     "hotel",
     "hourglass",
-    "house",
     "house_plug",
     "house_plus",
     "house_wifi",
+    "house",
     "ice_cream_bowl",
     "ice_cream_cone",
+    "id_card_lanyard",
     "id_card",
-    "image",
     "image_down",
     "image_minus",
     "image_off",
@@ -917,6 +931,7 @@ LUCIDE_ICON_LIST = [
     "image_plus",
     "image_up",
     "image_upscale",
+    "image",
     "images",
     "import",
     "inbox",
@@ -933,30 +948,30 @@ LUCIDE_ICON_LIST = [
     "japanese_yen",
     "joystick",
     "kanban",
-    "key",
     "key_round",
     "key_square",
-    "keyboard",
+    "key",
     "keyboard_music",
     "keyboard_off",
-    "lamp",
+    "keyboard",
     "lamp_ceiling",
     "lamp_desk",
     "lamp_floor",
     "lamp_wall_down",
     "lamp_wall_up",
+    "lamp",
     "land_plot",
     "landmark",
     "languages",
-    "laptop",
-    "laptop_minimal",
     "laptop_minimal_check",
-    "lasso",
+    "laptop_minimal",
+    "laptop",
     "lasso_select",
+    "lasso",
     "laugh",
-    "layers",
     "layers_2",
     "layers_3",
+    "layers",
     "layout_dashboard",
     "layout_grid",
     "layout_list",
@@ -967,24 +982,24 @@ LUCIDE_ICON_LIST = [
     "leafy_green",
     "lectern",
     "letter_text",
-    "library",
     "library_big",
+    "library",
     "life_buoy",
     "ligature",
-    "lightbulb",
     "lightbulb_off",
+    "lightbulb",
     "line_chart",
-    "link",
-    "link_2",
+    "line_squiggle",
     "link_2_off",
+    "link_2",
+    "link",
     "linkedin",
-    "list",
     "list_check",
     "list_checks",
     "list_collapse",
     "list_end",
-    "list_filter",
     "list_filter_plus",
+    "list_filter",
     "list_minus",
     "list_music",
     "list_ordered",
@@ -995,24 +1010,24 @@ LUCIDE_ICON_LIST = [
     "list_tree",
     "list_video",
     "list_x",
-    "loader",
+    "list",
     "loader_circle",
     "loader_pinwheel",
-    "locate",
+    "loader",
     "locate_fixed",
     "locate_off",
+    "locate",
     "location_edit",
-    "lock",
-    "lock_keyhole",
     "lock_keyhole_open",
+    "lock_keyhole",
     "lock_open",
+    "lock",
     "log_in",
     "log_out",
     "logs",
     "lollipop",
     "luggage",
     "magnet",
-    "mail",
     "mail_check",
     "mail_minus",
     "mail_open",
@@ -1021,34 +1036,35 @@ LUCIDE_ICON_LIST = [
     "mail_search",
     "mail_warning",
     "mail_x",
+    "mail",
     "mailbox",
     "mails",
-    "map",
-    "map_pin",
-    "map_pin_check",
+    "map_minus",
     "map_pin_check_inside",
+    "map_pin_check",
     "map_pin_house",
-    "map_pin_minus",
     "map_pin_minus_inside",
+    "map_pin_minus",
     "map_pin_off",
-    "map_pin_plus",
     "map_pin_plus_inside",
-    "map_pin_x",
+    "map_pin_plus",
     "map_pin_x_inside",
+    "map_pin_x",
+    "map_pin",
     "map_pinned",
     "map_plus",
+    "map",
     "mars_stroke",
     "martini",
-    "maximize",
     "maximize_2",
+    "maximize",
     "medal",
-    "megaphone",
     "megaphone_off",
+    "megaphone",
     "meh",
     "memory_stick",
     "menu",
     "merge",
-    "message_circle",
     "message_circle_code",
     "message_circle_dashed",
     "message_circle_heart",
@@ -1059,7 +1075,7 @@ LUCIDE_ICON_LIST = [
     "message_circle_reply",
     "message_circle_warning",
     "message_circle_x",
-    "message_square",
+    "message_circle",
     "message_square_code",
     "message_square_dashed",
     "message_square_diff",
@@ -1075,20 +1091,20 @@ LUCIDE_ICON_LIST = [
     "message_square_text",
     "message_square_warning",
     "message_square_x",
+    "message_square",
     "messages_square",
-    "mic",
     "mic_off",
     "mic_vocal",
+    "mic",
     "microchip",
     "microscope",
     "microwave",
     "milestone",
-    "milk",
     "milk_off",
-    "minimize",
+    "milk",
     "minimize_2",
+    "minimize",
     "minus",
-    "monitor",
     "monitor_check",
     "monitor_cog",
     "monitor_dot",
@@ -1101,60 +1117,60 @@ LUCIDE_ICON_LIST = [
     "monitor_stop",
     "monitor_up",
     "monitor_x",
-    "moon",
+    "monitor",
     "moon_star",
-    "mountain",
+    "moon",
     "mountain_snow",
-    "mouse",
+    "mountain",
     "mouse_off",
-    "mouse_pointer",
     "mouse_pointer_2",
     "mouse_pointer_ban",
     "mouse_pointer_click",
-    "move",
+    "mouse_pointer",
+    "mouse",
     "move_3d",
-    "move_diagonal",
     "move_diagonal_2",
-    "move_down",
+    "move_diagonal",
     "move_down_left",
     "move_down_right",
+    "move_down",
     "move_horizontal",
     "move_left",
     "move_right",
-    "move_up",
     "move_up_left",
     "move_up_right",
+    "move_up",
     "move_vertical",
-    "music",
+    "move",
     "music_2",
     "music_3",
     "music_4",
-    "navigation",
-    "navigation_2",
+    "music",
     "navigation_2_off",
+    "navigation_2",
     "navigation_off",
+    "navigation",
     "network",
     "newspaper",
     "nfc",
     "non_binary",
-    "notebook",
     "notebook_pen",
     "notebook_tabs",
     "notebook_text",
-    "notepad_text",
+    "notebook",
     "notepad_text_dashed",
-    "nut",
+    "notepad_text",
     "nut_off",
-    "octagon",
+    "nut",
     "octagon_alert",
     "octagon_minus",
     "octagon_pause",
     "octagon_x",
+    "octagon",
     "omega",
     "option",
     "orbit",
     "origami",
-    "package",
     "package_2",
     "package_check",
     "package_minus",
@@ -1162,29 +1178,30 @@ LUCIDE_ICON_LIST = [
     "package_plus",
     "package_search",
     "package_x",
+    "package",
     "paint_bucket",
     "paint_roller",
-    "paintbrush",
     "paintbrush_2",
     "paintbrush_vertical",
+    "paintbrush",
     "palette",
     "panda",
-    "panel_bottom",
     "panel_bottom_close",
     "panel_bottom_dashed",
     "panel_bottom_open",
-    "panel_left",
+    "panel_bottom",
     "panel_left_close",
     "panel_left_dashed",
     "panel_left_open",
-    "panel_right",
+    "panel_left",
     "panel_right_close",
     "panel_right_dashed",
     "panel_right_open",
-    "panel_top",
+    "panel_right",
     "panel_top_close",
     "panel_top_dashed",
     "panel_top_open",
+    "panel_top",
     "panels_left_bottom",
     "panels_right_bottom",
     "panels_top_left",
@@ -1195,63 +1212,63 @@ LUCIDE_ICON_LIST = [
     "pause",
     "paw_print",
     "pc_case",
-    "pen",
     "pen_line",
     "pen_off",
     "pen_tool",
-    "pencil",
+    "pen",
     "pencil_line",
     "pencil_off",
     "pencil_ruler",
+    "pencil",
     "pentagon",
     "percent",
     "person_standing",
     "philippine_peso",
-    "phone",
     "phone_call",
     "phone_forwarded",
     "phone_incoming",
     "phone_missed",
     "phone_off",
     "phone_outgoing",
+    "phone",
     "pi",
     "piano",
     "pickaxe",
-    "picture_in_picture",
     "picture_in_picture_2",
+    "picture_in_picture",
     "pie_chart",
     "piggy_bank",
-    "pilcrow",
     "pilcrow_left",
     "pilcrow_right",
-    "pill",
+    "pilcrow",
     "pill_bottle",
-    "pin",
+    "pill",
     "pin_off",
+    "pin",
     "pipette",
     "pizza",
-    "plane",
     "plane_landing",
     "plane_takeoff",
+    "plane",
     "play",
-    "plug",
     "plug_2",
-    "plug_zap",
     "plug_zap_2",
+    "plug_zap",
+    "plug",
     "plus",
-    "pocket",
     "pocket_knife",
+    "pocket",
     "podcast",
-    "pointer",
     "pointer_off",
+    "pointer",
     "popcorn",
     "popsicle",
     "pound_sterling",
-    "power",
     "power_off",
+    "power",
     "presentation",
-    "printer",
     "printer_check",
+    "printer",
     "projector",
     "proportions",
     "puzzle",
@@ -1262,15 +1279,14 @@ LUCIDE_ICON_LIST = [
     "radar",
     "radiation",
     "radical",
-    "radio",
     "radio_receiver",
     "radio_tower",
+    "radio",
     "radius",
     "rail_symbol",
     "rainbow",
     "rat",
     "ratio",
-    "receipt",
     "receipt_cent",
     "receipt_euro",
     "receipt_indian_rupee",
@@ -1279,62 +1295,64 @@ LUCIDE_ICON_LIST = [
     "receipt_russian_ruble",
     "receipt_swiss_franc",
     "receipt_text",
+    "receipt_turkish_lira",
+    "receipt",
+    "rectangle_circle",
     "rectangle_ellipsis",
     "rectangle_goggles",
     "rectangle_horizontal",
     "rectangle_vertical",
     "recycle",
-    "redo",
     "redo_2",
     "redo_dot",
-    "refresh_ccw",
+    "redo",
     "refresh_ccw_dot",
-    "refresh_cw",
+    "refresh_ccw",
     "refresh_cw_off",
+    "refresh_cw",
     "refrigerator",
     "regex",
     "remove_formatting",
-    "repeat",
     "repeat_1",
     "repeat_2",
-    "replace",
+    "repeat",
     "replace_all",
-    "reply",
+    "replace",
     "reply_all",
+    "reply",
     "rewind",
     "ribbon",
     "rocket",
     "rocking_chair",
     "roller_coaster",
     "rotate_3d",
-    "rotate_ccw",
     "rotate_ccw_key",
     "rotate_ccw_square",
-    "rotate_cw",
+    "rotate_ccw",
     "rotate_cw_square",
-    "route",
+    "rotate_cw",
     "route_off",
+    "route",
     "router",
     "rows_2",
     "rows_3",
     "rows_4",
     "rss",
-    "ruler",
     "ruler_dimension_line",
+    "ruler",
     "russian_ruble",
     "sailboat",
     "salad",
     "sandwich",
-    "satellite",
     "satellite_dish",
+    "satellite",
     "saudi_riyal",
-    "save",
     "save_all",
     "save_off",
-    "scale",
+    "save",
     "scale_3d",
+    "scale",
     "scaling",
-    "scan",
     "scan_barcode",
     "scan_eye",
     "scan_face",
@@ -1343,37 +1361,37 @@ LUCIDE_ICON_LIST = [
     "scan_qr_code",
     "scan_search",
     "scan_text",
+    "scan",
     "scatter_chart",
     "school",
-    "scissors",
     "scissors_line_dashed",
-    "screen_share",
+    "scissors",
     "screen_share_off",
-    "scroll",
+    "screen_share",
     "scroll_text",
-    "search",
+    "scroll",
     "search_check",
     "search_code",
     "search_slash",
     "search_x",
+    "search",
     "section",
-    "send",
     "send_horizontal",
     "send_to_back",
+    "send",
     "separator_horizontal",
     "separator_vertical",
-    "server",
     "server_cog",
     "server_crash",
     "server_off",
-    "settings",
+    "server",
     "settings_2",
+    "settings",
     "shapes",
-    "share",
     "share_2",
+    "share",
     "sheet",
     "shell",
-    "shield",
     "shield_alert",
     "shield_ban",
     "shield_check",
@@ -1385,8 +1403,9 @@ LUCIDE_ICON_LIST = [
     "shield_question",
     "shield_user",
     "shield_x",
-    "ship",
+    "shield",
     "ship_wheel",
+    "ship",
     "shirt",
     "shopping_bag",
     "shopping_basket",
@@ -1399,14 +1418,14 @@ LUCIDE_ICON_LIST = [
     "shrub",
     "shuffle",
     "sigma",
-    "signal",
     "signal_high",
     "signal_low",
     "signal_medium",
     "signal_zero",
+    "signal",
     "signature",
-    "signpost",
     "signpost_big",
+    "signpost",
     "siren",
     "skip_back",
     "skip_forward",
@@ -1416,11 +1435,11 @@ LUCIDE_ICON_LIST = [
     "slice",
     "sliders_horizontal",
     "sliders_vertical",
-    "smartphone",
     "smartphone_charging",
     "smartphone_nfc",
-    "smile",
+    "smartphone",
     "smile_plus",
+    "smile",
     "snail",
     "snowflake",
     "soap_dispenser_droplet",
@@ -1432,43 +1451,44 @@ LUCIDE_ICON_LIST = [
     "sparkles",
     "speaker",
     "speech",
-    "spell_check",
     "spell_check_2",
-    "spline",
+    "spell_check",
     "spline_pointer",
+    "spline",
     "split",
+    "spool",
+    "spotlight",
     "spray_can",
     "sprout",
-    "square",
     "square_activity",
-    "square_arrow_down",
     "square_arrow_down_left",
     "square_arrow_down_right",
+    "square_arrow_down",
     "square_arrow_left",
     "square_arrow_out_down_left",
     "square_arrow_out_down_right",
     "square_arrow_out_up_left",
     "square_arrow_out_up_right",
     "square_arrow_right",
-    "square_arrow_up",
     "square_arrow_up_left",
     "square_arrow_up_right",
+    "square_arrow_up",
     "square_asterisk",
     "square_bottom_dashed_scissors",
     "square_chart_gantt",
-    "square_check",
     "square_check_big",
+    "square_check",
     "square_chevron_down",
     "square_chevron_left",
     "square_chevron_right",
     "square_chevron_up",
     "square_code",
-    "square_dashed",
-    "square_dashed_bottom",
     "square_dashed_bottom_code",
+    "square_dashed_bottom",
     "square_dashed_kanban",
     "square_dashed_mouse_pointer",
     "square_dashed_top_solid",
+    "square_dashed",
     "square_divide",
     "square_dot",
     "square_equal",
@@ -1480,8 +1500,8 @@ LUCIDE_ICON_LIST = [
     "square_menu",
     "square_minus",
     "square_mouse_pointer",
-    "square_parking",
     "square_parking_off",
+    "square_parking",
     "square_pen",
     "square_percent",
     "square_pi",
@@ -1499,19 +1519,21 @@ LUCIDE_ICON_LIST = [
     "square_square",
     "square_stack",
     "square_terminal",
-    "square_user",
     "square_user_round",
+    "square_user",
     "square_x",
+    "square",
     "squares_exclude",
     "squares_intersect",
     "squares_subtract",
     "squares_unite",
+    "squircle_dashed",
     "squircle",
     "squirrel",
     "stamp",
-    "star",
     "star_half",
     "star_off",
+    "star",
     "step_back",
     "step_forward",
     "stethoscope",
@@ -1522,11 +1544,11 @@ LUCIDE_ICON_LIST = [
     "stretch_vertical",
     "strikethrough",
     "subscript",
-    "sun",
     "sun_dim",
     "sun_medium",
     "sun_moon",
     "sun_snow",
+    "sun",
     "sunrise",
     "sunset",
     "superscript",
@@ -1536,7 +1558,6 @@ LUCIDE_ICON_LIST = [
     "sword",
     "swords",
     "syringe",
-    "table",
     "table_2",
     "table_cells_merge",
     "table_cells_split",
@@ -1544,8 +1565,9 @@ LUCIDE_ICON_LIST = [
     "table_of_contents",
     "table_properties",
     "table_rows_split",
-    "tablet",
+    "table",
     "tablet_smartphone",
+    "tablet",
     "tablets",
     "tag",
     "tags",
@@ -1557,101 +1579,101 @@ LUCIDE_ICON_LIST = [
     "tangent",
     "target",
     "telescope",
-    "tent",
     "tent_tree",
+    "tent",
     "terminal",
-    "test_tube",
     "test_tube_diagonal",
+    "test_tube",
     "test_tubes",
-    "text",
-    "text_cursor",
     "text_cursor_input",
+    "text_cursor",
     "text_quote",
     "text_search",
     "text_select",
+    "text",
     "theater",
-    "thermometer",
     "thermometer_snowflake",
     "thermometer_sun",
+    "thermometer",
     "thumbs_down",
     "thumbs_up",
-    "ticket",
     "ticket_check",
     "ticket_minus",
     "ticket_percent",
     "ticket_plus",
     "ticket_slash",
     "ticket_x",
-    "tickets",
+    "ticket",
     "tickets_plane",
-    "timer",
+    "tickets",
     "timer_off",
     "timer_reset",
+    "timer",
     "toggle_left",
     "toggle_right",
     "toilet",
+    "tool_case",
     "tornado",
     "torus",
-    "touchpad",
     "touchpad_off",
+    "touchpad",
     "tower_control",
     "toy_brick",
     "tractor",
     "traffic_cone",
-    "train_front",
     "train_front_tunnel",
+    "train_front",
     "train_track",
     "tram_front",
     "transgender",
-    "trash",
     "trash_2",
+    "trash",
     "tree_deciduous",
     "tree_palm",
     "tree_pine",
     "trees",
     "trello",
     "trending_down",
-    "trending_up",
     "trending_up_down",
-    "triangle",
+    "trending_up",
     "triangle_alert",
     "triangle_dashed",
     "triangle_right",
+    "triangle",
     "trophy",
-    "truck",
     "truck_electric",
+    "truck",
+    "turkish_lira",
     "turtle",
-    "tv",
     "tv_2",
-    "tv_minimal",
     "tv_minimal_play",
+    "tv_minimal",
+    "tv",
     "twitch",
     "twitter",
-    "type",
     "type_outline",
-    "umbrella",
+    "type",
     "umbrella_off",
+    "umbrella",
     "underline",
-    "undo",
     "undo_2",
     "undo_dot",
+    "undo",
     "unfold_horizontal",
     "unfold_vertical",
     "ungroup",
     "university",
-    "unlink",
     "unlink_2",
+    "unlink",
     "unplug",
     "upload",
     "usb",
-    "user",
     "user_check",
     "user_cog",
     "user_lock",
     "user_minus",
     "user_pen",
     "user_plus",
-    "user_round",
     "user_round_check",
     "user_round_cog",
     "user_round_minus",
@@ -1659,80 +1681,80 @@ LUCIDE_ICON_LIST = [
     "user_round_plus",
     "user_round_search",
     "user_round_x",
+    "user_round",
     "user_search",
+    "user_star",
     "user_x",
-    "users",
+    "user",
     "users_round",
-    "utensils",
+    "users",
     "utensils_crossed",
+    "utensils",
     "utility_pole",
     "variable",
     "vault",
+    "vector_square",
     "vegan",
     "venetian_mask",
-    "venus",
     "venus_and_mars",
-    "vibrate",
+    "venus",
     "vibrate_off",
-    "video",
+    "vibrate",
     "video_off",
+    "video",
     "videotape",
     "view",
     "voicemail",
     "volleyball",
-    "volume",
     "volume_1",
     "volume_2",
     "volume_off",
     "volume_x",
+    "volume",
     "vote",
-    "wallet",
     "wallet_cards",
     "wallet_minimal",
+    "wallet",
     "wallpaper",
-    "wand",
     "wand_sparkles",
+    "wand",
     "warehouse",
     "washing_machine",
     "watch",
-    "waves",
     "waves_ladder",
+    "waves",
     "waypoints",
     "webcam",
-    "webhook",
     "webhook_off",
+    "webhook",
     "weight",
-    "wheat",
     "wheat_off",
+    "wheat",
     "whole_word",
-    "wifi",
+    "wifi_cog",
     "wifi_high",
     "wifi_low",
     "wifi_off",
     "wifi_pen",
+    "wifi_sync",
     "wifi_zero",
-    "wind",
+    "wifi",
     "wind_arrow_down",
-    "wine",
+    "wind",
     "wine_off",
+    "wine",
     "workflow",
     "worm",
     "wrap_text",
     "wrench",
     "x",
     "youtube",
-    "zap",
     "zap_off",
+    "zap",
     "zoom_in",
     "zoom_out",
 ]
 
 # The default transformation of some icon names doesn't match how the
 # icons are exported from Lucide. Manual overrides can go here.
-LUCIDE_ICON_MAPPING_OVERRIDE = {
-    "box_select": "BoxSelectIcon",
-    "grid_2x_2_check": "Grid2x2CheckIcon",
-    "grid_2x_2_x": "Grid2x2XIcon",
-    "grid_2x_2_plus": "Grid2x2PlusIcon",
-    "layers_3": "Layers3Icon",
-}
+LUCIDE_ICON_MAPPING_OVERRIDE = {"grid_3x2": "Grid3x2Icon"}
