@@ -10,7 +10,7 @@ import inspect
 import multiprocessing
 import os
 import platform
-from collections.abc import Callable
+from collections.abc import Callable, Sequence
 from functools import lru_cache
 from pathlib import Path
 from typing import (
@@ -227,7 +227,7 @@ def interpret_env_var_value(
         return interpret_existing_path_env(value, field_name)
     if field_type is Plugin:
         return interpret_plugin_env(value, field_name)
-    if get_origin(field_type) is list:
+    if get_origin(field_type) in (list, Sequence):
         return [
             interpret_env_var_value(
                 v,
@@ -563,16 +563,6 @@ class EnvironmentVariables:
     # Whether to skip purging the web directory in dev mode.
     REFLEX_PERSIST_WEB_DIR: EnvVar[bool] = env_var(False)
 
-    # The reflex.build frontend host.
-    REFLEX_BUILD_FRONTEND: EnvVar[str] = env_var(
-        constants.Templates.REFLEX_BUILD_FRONTEND
-    )
-
-    # The reflex.build backend host.
-    REFLEX_BUILD_BACKEND: EnvVar[str] = env_var(
-        constants.Templates.REFLEX_BUILD_BACKEND
-    )
-
     # This env var stores the execution mode of the app
     REFLEX_ENV_MODE: EnvVar[constants.Env] = env_var(constants.Env.DEV)
 
