@@ -2,6 +2,7 @@
 
 import dataclasses
 import inspect
+import sys
 import types
 import urllib.parse
 from base64 import b64encode
@@ -109,7 +110,7 @@ class EventActionsMixin:
         """
         return dataclasses.replace(
             self,
-            event_actions={"stopPropagation": True, **self.event_actions},
+            event_actions={**self.event_actions, "stopPropagation": True},
         )
 
     @property
@@ -121,7 +122,7 @@ class EventActionsMixin:
         """
         return dataclasses.replace(
             self,
-            event_actions={"preventDefault": True, **self.event_actions},
+            event_actions={**self.event_actions, "preventDefault": True},
         )
 
     def throttle(self, limit_ms: int) -> Self:
@@ -135,7 +136,7 @@ class EventActionsMixin:
         """
         return dataclasses.replace(
             self,
-            event_actions={"throttle": limit_ms, **self.event_actions},
+            event_actions={**self.event_actions, "throttle": limit_ms},
         )
 
     def debounce(self, delay_ms: int) -> Self:
@@ -149,7 +150,7 @@ class EventActionsMixin:
         """
         return dataclasses.replace(
             self,
-            event_actions={"debounce": delay_ms, **self.event_actions},
+            event_actions={**self.event_actions, "debounce": delay_ms},
         )
 
     @property
@@ -161,7 +162,7 @@ class EventActionsMixin:
         """
         return dataclasses.replace(
             self,
-            event_actions={"temporal": True, **self.event_actions},
+            event_actions={**self.event_actions, "temporal": True},
         )
 
 
@@ -403,7 +404,7 @@ class CallableEventSpec(EventSpec):
 
         Args:
             fn: The function to decorate.
-            **kwargs: The kwargs to pass to pydantic initializer
+            **kwargs: The kwargs to pass to the EventSpec constructor.
         """
         if fn is not None:
             default_event_spec = fn()
@@ -577,7 +578,7 @@ class JavascriptInputEvent:
     init=True,
     frozen=True,
 )
-class JavasciptKeyboardEvent:
+class JavascriptKeyboardEvent:
     """Interface for a Javascript KeyboardEvent https://developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent."""
 
     key: str = ""
@@ -635,6 +636,27 @@ def checked_input_event(e: ObjectVar[JavascriptInputEvent]) -> tuple[Var[bool]]:
     return (e.target.checked,)
 
 
+FORM_DATA = Var(_js_expr="form_data")
+
+
+def on_submit_event() -> tuple[Var[dict[str, Any]]]:
+    """Event handler spec for the on_submit event.
+
+    Returns:
+        The event handler spec.
+    """
+    return (FORM_DATA,)
+
+
+def on_submit_string_event() -> tuple[Var[dict[str, str]]]:
+    """Event handler spec for the on_submit event.
+
+    Returns:
+        The event handler spec.
+    """
+    return (FORM_DATA,)
+
+
 class KeyInputInfo(TypedDict):
     """Information about a key input event."""
 
@@ -645,7 +667,7 @@ class KeyInputInfo(TypedDict):
 
 
 def key_event(
-    e: ObjectVar[JavasciptKeyboardEvent],
+    e: ObjectVar[JavascriptKeyboardEvent],
 ) -> tuple[Var[str], Var[KeyInputInfo]]:
     """Get the key from a keyboard event.
 
@@ -1243,19 +1265,6 @@ def download(
     )
 
 
-# This function seems unused. Check if we still need it. If not, remove in 0.7.0
-def _callback_arg_spec(eval_result: Any):
-    """ArgSpec for call_script callback function.
-
-    Args:
-        eval_result: The result of the javascript execution.
-
-    Returns:
-        Args for the callback function
-    """
-    return [eval_result]
-
-
 def call_script(
     javascript_code: str | Var[str],
     callback: "EventType[Any] | None" = None,
@@ -1269,7 +1278,7 @@ def call_script(
     Returns:
         EventSpec: An event that will execute the client side javascript.
     """
-    callback_kwargs = {}
+    callback_kwargs = {"callback": None}
     if callback is not None:
         callback_kwargs = {
             "callback": str(
@@ -2197,7 +2206,9 @@ else:
 class EventNamespace:
     """A namespace for event related classes."""
 
+    # Core Event Classes
     Event = Event
+    EventActionsMixin = EventActionsMixin
     EventHandler = EventHandler
     EventSpec = EventSpec
     CallableEventSpec = CallableEventSpec
@@ -2206,12 +2217,56 @@ class EventNamespace:
     LiteralEventVar = LiteralEventVar
     EventChainVar = EventChainVar
     LiteralEventChainVar = LiteralEventChainVar
-    EventType = EventType
     EventCallback = EventCallback
+    LambdaEventCallback = LambdaEventCallback
+
+    # Javascript Event Classes
+    JavascriptHTMLInputElement = JavascriptHTMLInputElement
+    JavascriptInputEvent = JavascriptInputEvent
+    JavascriptKeyboardEvent = JavascriptKeyboardEvent
+    JavascriptMouseEvent = JavascriptMouseEvent
+    JavascriptPointerEvent = JavascriptPointerEvent
+
+    # Type Info Classes
+    KeyInputInfo = KeyInputInfo
+    MouseEventInfo = MouseEventInfo
+    PointerEventInfo = PointerEventInfo
+    IdentityEventReturn = IdentityEventReturn
+
+    # File Upload
+    FileUpload = FileUpload
+
+    # Type Aliases
+    EventType = EventType
+    LAMBDA_OR_STATE = LAMBDA_OR_STATE
+    BASIC_EVENT_TYPES = BASIC_EVENT_TYPES
+    IndividualEventType = IndividualEventType
+
+    # Constants
+    BACKGROUND_TASK_MARKER = BACKGROUND_TASK_MARKER
+    _EVENT_FIELDS = _EVENT_FIELDS
+    FORM_DATA = FORM_DATA
+    upload_files = upload_files
+    stop_propagation = stop_propagation
+    prevent_default = prevent_default
+
+    # Private/Internal Functions
+    _values_returned_from_event = staticmethod(_values_returned_from_event)
+    _check_event_args_subclass_of_callback = staticmethod(
+        _check_event_args_subclass_of_callback
+    )
 
     @overload
     def __new__(
-        cls, func: None = None, *, background: bool | None = None
+        cls,
+        func: None = None,
+        *,
+        background: bool | None = None,
+        stop_propagation: bool | None = None,
+        prevent_default: bool | None = None,
+        throttle: int | None = None,
+        debounce: int | None = None,
+        temporal: bool | None = None,
     ) -> Callable[
         [Callable[[BASE_STATE, Unpack[P]], Any]], EventCallback[Unpack[P]]  # pyright: ignore [reportInvalidTypeVarUse]
     ]: ...
@@ -2222,6 +2277,11 @@ class EventNamespace:
         func: Callable[[BASE_STATE, Unpack[P]], Any],
         *,
         background: bool | None = None,
+        stop_propagation: bool | None = None,
+        prevent_default: bool | None = None,
+        throttle: int | None = None,
+        debounce: int | None = None,
+        temporal: bool | None = None,
     ) -> EventCallback[Unpack[P]]: ...
 
     def __new__(
@@ -2229,6 +2289,11 @@ class EventNamespace:
         func: Callable[[BASE_STATE, Unpack[P]], Any] | None = None,
         *,
         background: bool | None = None,
+        stop_propagation: bool | None = None,
+        prevent_default: bool | None = None,
+        throttle: int | None = None,
+        debounce: int | None = None,
+        temporal: bool | None = None,
     ) -> (
         EventCallback[Unpack[P]]
         | Callable[[Callable[[BASE_STATE, Unpack[P]], Any]], EventCallback[Unpack[P]]]
@@ -2238,6 +2303,11 @@ class EventNamespace:
         Args:
             func: The function to wrap.
             background: Whether the event should be run in the background. Defaults to False.
+            stop_propagation: Whether to stop the event from bubbling up the DOM tree.
+            prevent_default: Whether to prevent the default behavior of the event.
+            throttle: Throttle the event handler to limit calls (in milliseconds).
+            debounce: Debounce the event handler to delay calls (in milliseconds).
+            temporal: Whether the event should be dropped when the backend is down.
 
         Raises:
             TypeError: If background is True and the function is not a coroutine or async generator. # noqa: DAR402
@@ -2246,6 +2316,30 @@ class EventNamespace:
             The wrapped function.
         """
 
+        def _build_event_actions():
+            """Build event_actions dict from decorator parameters.
+
+            Returns:
+                Dict of event actions to apply, or empty dict if none specified.
+            """
+            if not any(
+                [stop_propagation, prevent_default, throttle, debounce, temporal]
+            ):
+                return {}
+
+            event_actions = {}
+            if stop_propagation is not None:
+                event_actions["stopPropagation"] = stop_propagation
+            if prevent_default is not None:
+                event_actions["preventDefault"] = prevent_default
+            if throttle is not None:
+                event_actions["throttle"] = throttle
+            if debounce is not None:
+                event_actions["debounce"] = debounce
+            if temporal is not None:
+                event_actions["temporal"] = temporal
+            return event_actions
+
         def wrapper(
             func: Callable[[BASE_STATE, Unpack[P]], T],
         ) -> EventCallback[Unpack[P]]:
@@ -2281,8 +2375,22 @@ class EventNamespace:
                     object.__setattr__(func, "__name__", name)
                     object.__setattr__(func, "__qualname__", name)
                     state_cls._add_event_handler(name, func)
-                    return getattr(state_cls, name)
+                    event_callback = getattr(state_cls, name)
 
+                    # Apply decorator event actions
+                    event_actions = _build_event_actions()
+                    if event_actions:
+                        # Create new EventCallback with updated event_actions
+                        event_callback = dataclasses.replace(
+                            event_callback, event_actions=event_actions
+                        )
+
+                    return event_callback
+
+            # Store decorator event actions on the function for later processing
+            event_actions = _build_event_actions()
+            if event_actions:
+                func._rx_event_actions = event_actions  # pyright: ignore [reportFunctionMemberAccess]
             return func  # pyright: ignore [reportReturnType]
 
         if func is not None:
@@ -2298,10 +2406,22 @@ class EventNamespace:
     check_fn_match_arg_spec = staticmethod(check_fn_match_arg_spec)
     resolve_annotation = staticmethod(resolve_annotation)
     parse_args_spec = staticmethod(parse_args_spec)
+    unwrap_var_annotation = staticmethod(unwrap_var_annotation)
+    get_fn_signature = staticmethod(get_fn_signature)
+
+    # Event Spec Functions
     passthrough_event_spec = staticmethod(passthrough_event_spec)
     input_event = staticmethod(input_event)
+    int_input_event = staticmethod(int_input_event)
+    float_input_event = staticmethod(float_input_event)
+    checked_input_event = staticmethod(checked_input_event)
     key_event = staticmethod(key_event)
+    pointer_event_spec = staticmethod(pointer_event_spec)
     no_args_event_spec = staticmethod(no_args_event_spec)
+    on_submit_event = staticmethod(on_submit_event)
+    on_submit_string_event = staticmethod(on_submit_string_event)
+
+    # Server Side Events
     server_side = staticmethod(server_side)
     redirect = staticmethod(redirect)
     console_log = staticmethod(console_log)
@@ -2322,6 +2442,9 @@ class EventNamespace:
     call_script = staticmethod(call_script)
     call_function = staticmethod(call_function)
     run_script = staticmethod(run_script)
+    __file__ = __file__
 
 
 event = EventNamespace
+event.event = event  # pyright: ignore[reportAttributeAccessIssue]
+sys.modules[__name__] = event  # pyright: ignore[reportArgumentType]
